exceptiontools.PitchError
=========================

.. abjad-lineage:: abjad.tools.exceptiontools.PitchError.PitchError

.. autoclass:: abjad.tools.exceptiontools.PitchError.PitchError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.PitchError.PitchError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.PitchError.PitchError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.PitchError.PitchError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.PitchError.PitchError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.PitchError.PitchError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.PitchError.PitchError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.PitchError.PitchError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.PitchError.PitchError.__unicode__
   :noindex:
